@@ -20,6 +20,7 @@
 #include "loader.h"
 #include <linux/kernel_stat.h>
 #include <asm/dma.h>
+#include "ndis_exports.h"
 
 #define MAX_ALLOCATED_NDIS_PACKETS TX_RING_SIZE
 #define MAX_ALLOCATED_NDIS_BUFFERS TX_RING_SIZE
@@ -32,8 +33,6 @@ static spinlock_t ndis_work_list_lock;
 workqueue_struct_t *ndis_wq;
 static struct nt_thread *ndis_worker_thread;
 
-extern struct semaphore loader_mutex;
-
 static void *ndis_get_routine_address(char *name);
 
 wstdcall void WIN_FUNC(NdisInitializeWrapper,4)
@@ -56,7 +55,7 @@ wstdcall NDIS_STATUS WIN_FUNC(NdisMRegisterMiniport,3)
 {
 	int min_length;
 	struct wrap_driver *wrap_driver;
-	struct wrap_ndis_driver *ndis_driver;
+	struct ndis_driver *ndis_driver;
 
 	min_length = ((char *)&mp->co_create_vc) - ((char *)mp);
 
@@ -551,7 +550,7 @@ wstdcall void WIN_FUNC(NdisReadNetworkAddress,4)
 	(NDIS_STATUS *status, void **addr, UINT *len,
 	 struct ndis_mp_block *nmb)
 {
-	struct wrap_ndis_device *wnd = nmb->wnd;
+	struct ndis_device *wnd = nmb->wnd;
 	struct ndis_configuration_parameter *param;
 	struct unicode_string key;
 	struct ansi_string ansi;
@@ -662,7 +661,7 @@ wstdcall void WIN_FUNC(NdisMSetAttributesEx,5)
 	(struct ndis_mp_block *nmb, void *mp_ctx,
 	 UINT hangcheck_interval, UINT attributes, ULONG adaptertype)
 {
-	struct wrap_ndis_device *wnd;
+	struct ndis_device *wnd;
 
 	ENTER1("%p, %p, %d, %08x, %d", nmb, mp_ctx, hangcheck_interval,
 	       attributes, adaptertype);
@@ -765,7 +764,7 @@ wstdcall void WIN_FUNC(NdisMQueryAdapterResources,4)
 	(NDIS_STATUS *status, struct ndis_mp_block *nmb,
 	 NDIS_RESOURCE_LIST *resource_list, UINT *size)
 {
-	struct wrap_ndis_device *wnd = nmb->wnd;
+	struct ndis_device *wnd = nmb->wnd;
 	NDIS_RESOURCE_LIST *list;
 	UINT resource_length;
 
@@ -803,7 +802,7 @@ wstdcall NDIS_STATUS WIN_FUNC(NdisMPciAssignResources,3)
 	(struct ndis_mp_block *nmb, ULONG slot_number,
 	 NDIS_RESOURCE_LIST **resources)
 {
-	struct wrap_ndis_device *wnd = nmb->wnd;
+	struct ndis_device *wnd = nmb->wnd;
 
 	ENTER2("%p, %p", wnd, wnd->wd->resource_list);
 	*resources = &wnd->wd->resource_list->list->partial_resource_list;
@@ -811,10 +810,10 @@ wstdcall NDIS_STATUS WIN_FUNC(NdisMPciAssignResources,3)
 }
 
 wstdcall NDIS_STATUS WIN_FUNC(NdisMMapIoSpace,4)
-	(void **virt, struct ndis_mp_block *nmb,
+	(void __iomem **virt, struct ndis_mp_block *nmb,
 	 NDIS_PHY_ADDRESS phy_addr, UINT len)
 {
-	struct wrap_ndis_device *wnd = nmb->wnd;
+	struct ndis_device *wnd = nmb->wnd;
 
 	ENTER2("%Lx, %d", phy_addr, len);
 	*virt = MmMapIoSpace(phy_addr, len, MmCached);
@@ -829,7 +828,7 @@ wstdcall NDIS_STATUS WIN_FUNC(NdisMMapIoSpace,4)
 }
 
 wstdcall void WIN_FUNC(NdisMUnmapIoSpace,3)
-	(struct ndis_mp_block *nmb, void *virt, UINT len)
+	(struct ndis_mp_block *nmb, void __iomem *virt, UINT len)
 {
 	ENTER2("%p, %d", virt, len);
 	MmUnmapIoSpace(virt, len);
@@ -842,14 +841,14 @@ wstdcall void WIN_FUNC(NdisAllocateSpinLock,1)
 	TRACE4("lock %p, %p", lock, &lock->klock);
 	KeInitializeSpinLock(&lock->klock);
 	lock->irql = PASSIVE_LEVEL;
-	EXIT4(return);
+	return;
 }
 
 wstdcall void WIN_FUNC(NdisFreeSpinLock,1)
 	(struct ndis_spinlock *lock)
 {
 	TRACE4("lock %p, %p", lock, &lock->klock);
-	EXIT4(return);
+	return;
 }
 
 wstdcall void WIN_FUNC(NdisAcquireSpinLock,1)
@@ -858,7 +857,7 @@ wstdcall void WIN_FUNC(NdisAcquireSpinLock,1)
 	ENTER6("lock %p, %p", lock, &lock->klock);
 //	assert_irql(_irql_ <= DISPATCH_LEVEL);
 	lock->irql = nt_spin_lock_irql(&lock->klock, DISPATCH_LEVEL);
-	EXIT6(return);
+	return;
 }
 
 wstdcall void WIN_FUNC(NdisReleaseSpinLock,1)
@@ -867,7 +866,7 @@ wstdcall void WIN_FUNC(NdisReleaseSpinLock,1)
 	ENTER6("lock %p, %p", lock, &lock->klock);
 //	assert_irql(_irql_ == DISPATCH_LEVEL);
 	nt_spin_unlock_irql(&lock->klock, lock->irql);
-	EXIT6(return);
+	return;
 }
 
 wstdcall void WIN_FUNC(NdisDprAcquireSpinLock,1)
@@ -876,7 +875,7 @@ wstdcall void WIN_FUNC(NdisDprAcquireSpinLock,1)
 	ENTER6("lock %p", &lock->klock);
 //	assert_irql(_irql_ == DISPATCH_LEVEL);
 	nt_spin_lock(&lock->klock);
-	EXIT6(return);
+	return;
 }
 
 wstdcall void WIN_FUNC(NdisDprReleaseSpinLock,1)
@@ -885,7 +884,7 @@ wstdcall void WIN_FUNC(NdisDprReleaseSpinLock,1)
 	ENTER6("lock %p", &lock->klock);
 //	assert_irql(_irql_ == DISPATCH_LEVEL);
 	nt_spin_unlock(&lock->klock);
-	EXIT6(return);
+	return;
 }
 
 wstdcall void WIN_FUNC(NdisInitializeReadWriteLock,1)
@@ -894,7 +893,7 @@ wstdcall void WIN_FUNC(NdisInitializeReadWriteLock,1)
 	ENTER3("%p", rw_lock);
 	memset(rw_lock, 0, sizeof(*rw_lock));
 	KeInitializeSpinLock(&rw_lock->klock);
-	EXIT3(return);
+	return;
 }
 
 /* read/write locks are implemented in a rather simplisitic way - we
@@ -937,7 +936,7 @@ wstdcall NDIS_STATUS WIN_FUNC(NdisMAllocateMapRegisters,5)
 	(struct ndis_mp_block *nmb, UINT dmachan,
 	 NDIS_DMA_SIZE dmasize, ULONG basemap, ULONG max_buf_size)
 {
-	struct wrap_ndis_device *wnd = nmb->wnd;
+	struct ndis_device *wnd = nmb->wnd;
 
 	ENTER2("%p, %d %d %d %d", wnd, dmachan, dmasize, basemap, max_buf_size);
 	if (wnd->dma_map_count > 0) {
@@ -989,7 +988,7 @@ wstdcall NDIS_STATUS WIN_FUNC(NdisMAllocateMapRegisters,5)
 wstdcall void WIN_FUNC(NdisMFreeMapRegisters,1)
 	(struct ndis_mp_block *nmb)
 {
-	struct wrap_ndis_device *wnd = nmb->wnd;
+	struct ndis_device *wnd = nmb->wnd;
 	int i;
 
 	ENTER2("wnd: %p", wnd);
@@ -1013,7 +1012,7 @@ wstdcall void WIN_FUNC(NdisMStartBufferPhysicalMapping,6)
 	 ULONG index, BOOLEAN write_to_dev,
 	 struct ndis_phy_addr_unit *phy_addr_array, UINT *array_size)
 {
-	struct wrap_ndis_device *wnd = nmb->wnd;
+	struct ndis_device *wnd = nmb->wnd;
 
 	ENTER3("%p, %p, %u, %u", wnd, buf, index, wnd->dma_map_count);
 	if (unlikely(wnd->sg_dma_size || !write_to_dev ||
@@ -1051,7 +1050,7 @@ wstdcall void WIN_FUNC(NdisMStartBufferPhysicalMapping,6)
 wstdcall void WIN_FUNC(NdisMCompleteBufferPhysicalMapping,3)
 	(struct ndis_mp_block *nmb, ndis_buffer *buf, ULONG index)
 {
-	struct wrap_ndis_device *wnd = nmb->wnd;
+	struct ndis_device *wnd = nmb->wnd;
 
 	ENTER3("%p, %p %u (%u)", wnd, buf, index, wnd->dma_map_count);
 
@@ -1100,7 +1099,7 @@ wstdcall void WIN_FUNC(NdisMFreeSharedMemory,5)
 
 wstdcall void alloc_shared_memory_async(void *arg1, void *arg2)
 {
-	struct wrap_ndis_device *wnd;
+	struct ndis_device *wnd;
 	struct alloc_shared_mem *alloc_shared_mem;
 	struct miniport *mp;
 	void *virt;
@@ -1124,7 +1123,7 @@ WIN_FUNC_DECL(alloc_shared_memory_async,2)
 wstdcall NDIS_STATUS WIN_FUNC(NdisMAllocateSharedMemoryAsync,4)
 	(struct ndis_mp_block *nmb, ULONG size, BOOLEAN cached, void *ctx)
 {
-	struct wrap_ndis_device *wnd = nmb->wnd;
+	struct ndis_device *wnd = nmb->wnd;
 	struct alloc_shared_mem *alloc_shared_mem;
 
 	ENTER3("wnd: %p", wnd);
@@ -1185,7 +1184,7 @@ wstdcall void WIN_FUNC(NdisAllocateBuffer,5)
 {
 	ndis_buffer *descr;
 
-	ENTER4("pool: %p, allocated: %d", pool, pool->num_allocated_descr);
+	ENTER4("pool: %p (%d)", pool, pool->num_allocated_descr);
 	/* NDIS drivers should call this at DISPATCH_LEVEL, but
 	 * alloc_tx_packet calls at SOFT_IRQL */
 	assert_irql(_irql_ <= SOFT_LEVEL);
@@ -1247,16 +1246,15 @@ wstdcall void WIN_FUNC(NdisFreeBuffer,1)
 		EXIT4(return);
 	}
 	pool = buffer->pool;
-	spin_lock_bh(&pool->lock);
 	if (pool->num_allocated_descr > MAX_ALLOCATED_NDIS_BUFFERS) {
 		/* NB NB NB: set mdl's 'pool' field to NULL before
 		 * calling free_mdl; otherwise free_mdl calls
-		 * NdisFreeBuffer causing deadlock (for spinlock) */
-		pool->num_allocated_descr--;
+		 * NdisFreeBuffer back */
+		atomic_dec_var(pool->num_allocated_descr);
 		buffer->pool = NULL;
-		spin_unlock_bh(&pool->lock);
 		free_mdl(buffer);
 	} else {
+		spin_lock_bh(&pool->lock);
 		buffer->next = pool->free_descr;
 		pool->free_descr = buffer;
 		spin_unlock_bh(&pool->lock);
@@ -1530,7 +1528,7 @@ wstdcall void WIN_FUNC(NdisAllocatePacket,3)
 		}
 		atomic_inc_var(pool->num_allocated_descr);
 	}
-	TRACE4("%p, %p, %p", pool, packet, pool->free_descr);
+	TRACE4("%p, %p", pool, packet);
 	atomic_inc_var(pool->num_used_descr);
 	memset(packet, 0, packet_length);
 	packet->private.oob_offset =
@@ -1554,30 +1552,31 @@ wstdcall void WIN_FUNC(NdisFreePacket,1)
 {
 	struct ndis_packet_pool *pool;
 
-	ENTER4("packet: %p, pool: %p", packet, packet->private.pool);
+	ENTER4("%p, %p", packet, packet->private.pool);
 	pool = packet->private.pool;
 	if (!pool) {
-		ERROR("pool for descriptor %p is invalid", packet);
+		ERROR("invalid pool %p", packet);
 		EXIT4(return);
 	}
-	spin_lock_bh(&pool->lock);
-	pool->num_used_descr--;
+	assert((int)pool->num_used_descr > 0);
+	atomic_dec_var(pool->num_used_descr);
 	if (packet->reserved[1]) {
 		TRACE3("%p, %p", packet, (void *)packet->reserved[1]);
 		kfree((void *)packet->reserved[1]);
 		packet->reserved[1] = 0;
 	}
 	if (pool->num_allocated_descr > MAX_ALLOCATED_NDIS_PACKETS) {
-		TRACE3("%p", packet);
-		pool->num_allocated_descr--;
+		TRACE3("%p", pool);
+		atomic_dec_var(pool->num_allocated_descr);
 		kfree(packet);
 	} else {
 		TRACE4("%p, %p, %p", pool, packet, pool->free_descr);
+		spin_lock_bh(&pool->lock);
 		packet->reserved[0] =
 			(typeof(packet->reserved[0]))pool->free_descr;
 		pool->free_descr = packet;
+		spin_unlock_bh(&pool->lock);
 	}
-	spin_unlock_bh(&pool->lock);
 	EXIT4(return);
 }
 
@@ -1692,7 +1691,7 @@ wstdcall void WIN_FUNC(NdisSend,3)
 	(NDIS_STATUS *status, struct ndis_mp_block *nmb,
 	 struct ndis_packet *packet)
 {
-	struct wrap_ndis_device *wnd = nmb->wnd;
+	struct ndis_device *wnd = nmb->wnd;
 	struct miniport *mp;
 	KIRQL irql;
 
@@ -1839,7 +1838,7 @@ wstdcall void WIN_FUNC(NdisCancelTimer,2)
 wstdcall void WIN_FUNC(NdisMRegisterAdapterShutdownHandler,3)
 	(struct ndis_mp_block *nmb, void *ctx, void *func)
 {
-	struct wrap_ndis_device *wnd = nmb->wnd;
+	struct ndis_device *wnd = nmb->wnd;
 	ENTER1("%p", func);
 	wnd->wd->driver->ndis_driver->mp.shutdown = func;
 	wnd->shutdown_ctx = ctx;
@@ -1848,7 +1847,7 @@ wstdcall void WIN_FUNC(NdisMRegisterAdapterShutdownHandler,3)
 wstdcall void WIN_FUNC(NdisMDeregisterAdapterShutdownHandler,1)
 	(struct ndis_mp_block *nmb)
 {
-	struct wrap_ndis_device *wnd = nmb->wnd;
+	struct ndis_device *wnd = nmb->wnd;
 	wnd->wd->driver->ndis_driver->mp.shutdown = NULL;
 	wnd->shutdown_ctx = NULL;
 }
@@ -1862,7 +1861,7 @@ wstdcall void WIN_FUNC(NdisMDeregisterAdapterShutdownHandler,1)
 wstdcall void deserialized_irq_handler(struct kdpc *kdpc, void *ctx,
 				       void *arg1, void *arg2)
 {
-	struct wrap_ndis_device *wnd = ctx;
+	struct ndis_device *wnd = ctx;
 	ndis_interrupt_handler irq_handler = arg1;
 	struct miniport *mp = arg2;
 
@@ -1878,10 +1877,10 @@ WIN_FUNC_DECL(deserialized_irq_handler,4)
 wstdcall void serialized_irq_handler(struct kdpc *kdpc, void *ctx,
 				     void *arg1, void *arg2)
 {
-	struct wrap_ndis_device *wnd = ctx;
+	struct ndis_device *wnd = ctx;
 	ndis_interrupt_handler irq_handler = arg1;
 
-	TRACE6("%p", irq_handler);
+	TRACE6("%p, %p, %p", wnd, irq_handler, arg2);
 	assert_irql(_irql_ == DISPATCH_LEVEL);
 	serialize_lock(wnd);
 	LIN2WIN1(irq_handler, arg2);
@@ -1893,7 +1892,7 @@ WIN_FUNC_DECL(serialized_irq_handler,4)
 wstdcall BOOLEAN ndis_isr(struct kinterrupt *kinterrupt, void *ctx)
 {
 	struct ndis_mp_interrupt *mp_interrupt = ctx;
-	struct wrap_ndis_device *wnd = mp_interrupt->nmb->wnd;
+	struct ndis_device *wnd = mp_interrupt->nmb->wnd;
 	BOOLEAN recognized, queue_handler;
 
 	TRACE6("%p", wnd);
@@ -1926,7 +1925,7 @@ wstdcall NDIS_STATUS WIN_FUNC(NdisMRegisterInterrupt,7)
 	 struct ndis_mp_block *nmb, UINT vector, UINT level,
 	 BOOLEAN req_isr, BOOLEAN shared, enum kinterrupt_mode mode)
 {
-	struct wrap_ndis_device *wnd = nmb->wnd;
+	struct ndis_device *wnd = nmb->wnd;
 	struct miniport *mp;
 
 	ENTER1("%p, vector:%d, level:%d, req_isr:%d, shared:%d, mode:%d",
@@ -1962,8 +1961,8 @@ wstdcall NDIS_STATUS WIN_FUNC(NdisMRegisterInterrupt,7)
 				nmb->wnd);
 		wnd->irq_kdpc.arg1 = mp->handle_interrupt;
 		wnd->irq_kdpc.arg2 = nmb->mp_ctx;
-		TRACE2("%p, %p, %p, %p", wnd->irq_kdpc.arg1, wnd->irq_kdpc.arg2,
-		       nmb->wnd, nmb->mp_ctx);
+		TRACE2("%p, %p, %p", wnd->irq_kdpc.arg1, wnd->irq_kdpc.arg2,
+		       nmb->wnd);
 	}
 
 	if (IoConnectInterrupt(&mp_interrupt->kinterrupt,
@@ -1993,6 +1992,7 @@ wstdcall void WIN_FUNC(NdisMDeregisterInterrupt,1)
 	nmb->wnd->mp_interrupt = NULL;
 	if (dequeue_kdpc(&nmb->wnd->irq_kdpc))
 		TRACE2("interrupt kdpc was pending");
+	flush_workqueue(wrapndis_wq);
 	IoDisconnectInterrupt(mp_interrupt->kinterrupt);
 	EXIT1(return);
 }
@@ -2008,10 +2008,8 @@ wstdcall BOOLEAN WIN_FUNC(NdisMSynchronizeWithInterrupt,3)
 wstdcall void WIN_FUNC(NdisMIndicateStatus,4)
 	(struct ndis_mp_block *nmb, NDIS_STATUS status, void *buf, UINT len)
 {
-	struct wrap_ndis_device *wnd = nmb->wnd;
+	struct ndis_device *wnd = nmb->wnd;
 	struct ndis_status_indication *si;
-	struct ndis_auth_req *auth_req;
-	struct ndis_radio_status_indication *radio_status;
 
 	ENTER2("status=0x%x len=%d", status, len);
 	switch (status) {
@@ -2021,8 +2019,8 @@ wstdcall void WIN_FUNC(NdisMIndicateStatus,4)
 		if (netif_queue_stopped(wnd->net_dev))
 			netif_wake_queue(wnd->net_dev);
 		if (wnd->physical_medium == NdisPhysicalMediumWirelessLan) {
-			set_bit(LINK_STATUS_ON, &wnd->wrap_ndis_pending_work);
-			schedule_wrapndis_work(&wnd->wrap_ndis_work);
+			set_bit(LINK_STATUS_ON, &wnd->ndis_pending_work);
+			schedule_wrapndis_work(&wnd->ndis_work);
 		}
 		break;
 	case NDIS_STATUS_MEDIA_DISCONNECT:
@@ -2031,8 +2029,8 @@ wstdcall void WIN_FUNC(NdisMIndicateStatus,4)
 		wnd->tx_ok = 0;
 		if (wnd->physical_medium == NdisPhysicalMediumWirelessLan) {
 			memset(&wnd->essid, 0, sizeof(wnd->essid));
-			set_bit(LINK_STATUS_OFF, &wnd->wrap_ndis_pending_work);
-			schedule_wrapndis_work(&wnd->wrap_ndis_work);
+			set_bit(LINK_STATUS_OFF, &wnd->ndis_pending_work);
+			schedule_wrapndis_work(&wnd->ndis_work);
 		}
 		break;
 	case NDIS_STATUS_MEDIA_SPECIFIC_INDICATION:
@@ -2049,7 +2047,8 @@ wstdcall void WIN_FUNC(NdisMIndicateStatus,4)
 			len -= sizeof(*si);
 			while (len > 0) {
 				int pairwise_error = 0, group_error = 0;
-				auth_req = (struct ndis_auth_req *)buf;
+				struct ndis_auth_req *auth_req =
+					(struct ndis_auth_req *)buf;
 				TRACE1(MACSTRSEP, MAC2STR(auth_req->bssid));
 				if (auth_req->flags & 0x01)
 					TRACE2("reauth request");
@@ -2063,7 +2062,6 @@ wstdcall void WIN_FUNC(NdisMIndicateStatus,4)
 					group_error = 1;
 					TRACE2("group_error");
 				}
-#if WIRELESS_EXT > 17
 				if (pairwise_error || group_error) {
 					union iwreq_data wrqu;
 					struct iw_michaelmicfailure micfailure;
@@ -2083,7 +2081,6 @@ wstdcall void WIN_FUNC(NdisMIndicateStatus,4)
 							    IWEVMICHAELMICFAILURE,
 							    &wrqu, (u8 *)&micfailure);
 				}
-#endif
 				len -= auth_req->length;
 				buf = (char *)buf + auth_req->length;
 			}
@@ -2106,10 +2103,8 @@ wstdcall void WIN_FUNC(NdisMIndicateStatus,4)
 			TRACE2("PMKID ver %d num_cand %d",
 			       cand->version, cand->num_candidates);
 			for (i = 0; i < cand->num_candidates; i++) {
-#if WIRELESS_EXT > 17
 				struct iw_pmkid_cand pcand;
 				union iwreq_data wrqu;
-#endif
 				struct ndis_pmkid_candidate *c =
 					&cand->candidates[i];
 				if ((u8 *)(c + 1) > end) {
@@ -2118,7 +2113,6 @@ wstdcall void WIN_FUNC(NdisMIndicateStatus,4)
 				}
 				TRACE2("%ld: " MACSTRSEP " 0x%x",
 				       i, MAC2STR(c->bssid), c->flags);
-#if WIRELESS_EXT > 17
 				memset(&pcand, 0, sizeof(pcand));
 				if (c->flags & 0x01)
 					pcand.flags |= IW_PMKID_CAND_PREAUTH;
@@ -2129,12 +2123,12 @@ wstdcall void WIN_FUNC(NdisMIndicateStatus,4)
 				wrqu.data.length = sizeof(pcand);
 				wireless_send_event(wnd->net_dev, IWEVPMKIDCAND,
 						    &wrqu, (u8 *)&pcand);
-#endif
 			}
 			break;
 		}
 		case Ndis802_11StatusType_RadioState:
-			radio_status = buf;
+		{
+			struct ndis_radio_status_indication *radio_status = buf;
 			if (radio_status->radio_state ==
 			    Ndis802_11RadioStatusOn)
 				INFO("radio is turned on");
@@ -2145,6 +2139,7 @@ wstdcall void WIN_FUNC(NdisMIndicateStatus,4)
 				 Ndis802_11RadioStatusSoftwareOff)
 				INFO("radio is turned off by software");
 			break;
+		}
 #endif
 		default:
 			/* is this RSSI indication? */
@@ -2164,7 +2159,7 @@ wstdcall void WIN_FUNC(NdisMIndicateStatus,4)
 wstdcall void WIN_FUNC(NdisMIndicateStatusComplete,1)
 	(struct ndis_mp_block *nmb)
 {
-	struct wrap_ndis_device *wnd = nmb->wnd;
+	struct ndis_device *wnd = nmb->wnd;
 	ENTER2("%p", wnd);
 	if (wnd->tx_ok)
 		schedule_wrapndis_work(&wnd->tx_work);
@@ -2174,7 +2169,7 @@ wstdcall void WIN_FUNC(NdisMIndicateStatusComplete,1)
 wstdcall void NdisMSendComplete(struct ndis_mp_block *nmb,
 				struct ndis_packet *packet, NDIS_STATUS status)
 {
-	struct wrap_ndis_device *wnd = nmb->wnd;
+	struct ndis_device *wnd = nmb->wnd;
 	ENTER4("%p, %08X", packet, status);
 	assert_irql(_irql_ <= DISPATCH_LEVEL);
 	if (deserialized_driver(wnd))
@@ -2210,7 +2205,7 @@ wstdcall void NdisMSendComplete(struct ndis_mp_block *nmb,
 /* called via function pointer */
 wstdcall void NdisMSendResourcesAvailable(struct ndis_mp_block *nmb)
 {
-	struct wrap_ndis_device *wnd = nmb->wnd;
+	struct ndis_device *wnd = nmb->wnd;
 	ENTER3("%d, %d", wnd->tx_ring_start, wnd->tx_ring_end);
 	wnd->tx_ok = 1;
 	schedule_wrapndis_work(&wnd->tx_work);
@@ -2219,7 +2214,7 @@ wstdcall void NdisMSendResourcesAvailable(struct ndis_mp_block *nmb)
 
 wstdcall void return_packet(void *arg1, void *arg2)
 {
-	struct wrap_ndis_device *wnd;
+	struct ndis_device *wnd;
 	struct ndis_packet *packet;
 	struct miniport *mp;
 	KIRQL irql;
@@ -2241,7 +2236,7 @@ wstdcall void NdisMIndicateReceivePacket(struct ndis_mp_block *nmb,
 					 struct ndis_packet **packets,
 					 UINT nr_packets)
 {
-	struct wrap_ndis_device *wnd;
+	struct ndis_device *wnd;
 	ndis_buffer *buffer;
 	struct ndis_packet *packet;
 	struct sk_buff *skb;
@@ -2332,7 +2327,7 @@ wstdcall void EthRxIndicateHandler(struct ndis_mp_block *nmb, void *rx_ctx,
 				   UINT packet_size)
 {
 	struct sk_buff *skb = NULL;
-	struct wrap_ndis_device *wnd;
+	struct ndis_device *wnd;
 	unsigned int skb_size = 0;
 	KIRQL irql;
 	struct ndis_packet_oob_data *oob_data;
@@ -2449,7 +2444,7 @@ wstdcall void NdisMTransferDataComplete(struct ndis_mp_block *nmb,
 					struct ndis_packet *packet,
 					NDIS_STATUS status, UINT bytes_txed)
 {
-	struct wrap_ndis_device *wnd = nmb->wnd;
+	struct ndis_device *wnd = nmb->wnd;
 	struct sk_buff *skb;
 	unsigned int skb_size;
 	struct ndis_packet_oob_data *oob_data;
@@ -2514,7 +2509,7 @@ wstdcall void EthRxComplete(struct ndis_mp_block *nmb)
 wstdcall void NdisMQueryInformationComplete(struct ndis_mp_block *nmb,
 					    NDIS_STATUS status)
 {
-	struct wrap_ndis_device *wnd = nmb->wnd;
+	struct ndis_device *wnd = nmb->wnd;
 	typeof(wnd->ndis_req_task) task;
 
 	ENTER2("nmb: %p, wnd: %p, %08X", nmb, wnd, status);
@@ -2531,7 +2526,7 @@ wstdcall void NdisMQueryInformationComplete(struct ndis_mp_block *nmb,
 wstdcall void NdisMSetInformationComplete(struct ndis_mp_block *nmb,
 					  NDIS_STATUS status)
 {
-	struct wrap_ndis_device *wnd = nmb->wnd;
+	struct ndis_device *wnd = nmb->wnd;
 	typeof(wnd->ndis_req_task) task;
 
 	ENTER2("status = %08X", status);
@@ -2548,7 +2543,7 @@ wstdcall void NdisMSetInformationComplete(struct ndis_mp_block *nmb,
 wstdcall void NdisMResetComplete(struct ndis_mp_block *nmb,
 				 NDIS_STATUS status, BOOLEAN address_reset)
 {
-	struct wrap_ndis_device *wnd = nmb->wnd;
+	struct ndis_device *wnd = nmb->wnd;
 	typeof(wnd->ndis_req_task) task;
 
 	ENTER2("status: %08X, %u", status, address_reset);
@@ -2614,7 +2609,7 @@ wstdcall struct nt_list *WIN_FUNC(NdisInterlockedRemoveHeadList,2)
 wstdcall NDIS_STATUS WIN_FUNC(NdisMInitializeScatterGatherDma,3)
 	(struct ndis_mp_block *nmb, BOOLEAN dma_size, ULONG max_phy_map)
 {
-	struct wrap_ndis_device *wnd = nmb->wnd;
+	struct ndis_device *wnd = nmb->wnd;
 	ENTER2("dma_size=%d, maxtransfer=%u", dma_size, max_phy_map);
 #ifdef CONFIG_X86_64
 	if (dma_size != NDIS_DMA_64BITS) {
@@ -2637,11 +2632,7 @@ wstdcall ULONG WIN_FUNC(NdisMGetDmaAlignment,1)
 	(struct ndis_mp_block *nmb)
 {
 	ENTER3("");
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,0)
 	return dma_get_cache_alignment();
-#else
-	return L1_CACHE_BYTES;
-#endif
 }
 
 wstdcall CHAR WIN_FUNC(NdisSystemProcessorCount,0)
@@ -2654,14 +2645,9 @@ wstdcall void WIN_FUNC(NdisGetCurrentProcessorCounts,3)
 	(ULONG *idle, ULONG *kernel_user, ULONG *index)
 {
 	int cpu = smp_processor_id();
-#if LINUX_VERSION_CODE > KERNEL_VERSION(2,6,10)
 	*idle = kstat_cpu(cpu).cpustat.idle;
 	*kernel_user = kstat_cpu(cpu).cpustat.system +
 		kstat_cpu(cpu).cpustat.user;
-#else
-	*idle = 0;
-	*kernel_user = 0;
-#endif
 	*index = cpu;
 }
 
@@ -2768,7 +2754,7 @@ wstdcall UINT WIN_FUNC(NdisGetVersion,0)
 wstdcall NDIS_STATUS WIN_FUNC(NdisMQueryAdapterInstanceName,2)
 	(struct unicode_string *name, struct ndis_mp_block *nmb)
 {
-	struct wrap_ndis_device *wnd = nmb->wnd;
+	struct ndis_device *wnd = nmb->wnd;
 	struct ansi_string ansi;
 
 	if (wrap_is_pci_bus(wnd->wd->dev_bus))
@@ -2843,7 +2829,7 @@ wstdcall void WIN_FUNC(NdisMCoRequestComplete,3)
 	(NDIS_STATUS status, struct ndis_mp_block *nmb,
 	 struct ndis_request *ndis_request)
 {
-	struct wrap_ndis_device *wnd = nmb->wnd;
+	struct ndis_device *wnd = nmb->wnd;
 	typeof(wnd->ndis_req_task) task;
 
 	ENTER3("%08X", status);
@@ -2908,8 +2894,6 @@ wstdcall void WIN_FUNC(NdisMRemoveMiniport,1)
 	TODO();
 }
 
-#include "ndis_exports.h"
-
 static void *ndis_get_routine_address(char *name)
 {
 	int i;
@@ -2924,7 +2908,7 @@ static void *ndis_get_routine_address(char *name)
 }
 
 /* ndis_init_device is called for each device */
-int ndis_init_device(struct wrap_ndis_device *wnd)
+int ndis_init_device(struct ndis_device *wnd)
 {
 	struct ndis_mp_block *nmb = wnd->nmb;
 
@@ -2954,7 +2938,7 @@ int ndis_init_device(struct wrap_ndis_device *wnd)
 }
 
 /* ndis_exit_device is called for each device */
-void ndis_exit_device(struct wrap_ndis_device *wnd)
+void ndis_exit_device(struct ndis_device *wnd)
 {
 	struct wrap_device_setting *setting;
 	ENTER2("%p", wnd);
